@@ -1,6 +1,7 @@
 /*
  * Copyright (C) 2003-2008  Justin Karneges <justin@affinix.com>
  * Copyright (C) 2004,2005  Brad Hards <bradh@frogmouth.net>
+ * Copyright (C) 2014-2016  Ivan Romanov <drizt@land.ru>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -481,6 +482,8 @@ QStringList pluginPaths()
 #ifndef DEVELOPER_MODE
 	paths.removeDuplicates();
 #endif
+	// No empty strings
+	paths.removeAll(QString());
 	return paths;
 }
 
@@ -810,6 +813,16 @@ QByteArray hexToArray(const QString &str)
 	return Hex().stringToArray(str).toByteArray();
 }
 
+QString arrayToBase64(const QByteArray &a)
+{
+	return Base64().arrayToString(a);
+}
+
+QByteArray base64ToArray(const QString &base64String)
+{
+	return Base64().stringToArray(base64String).toByteArray();
+}
+
 static Provider *getProviderForType(const QString &type, const QString &provider)
 {
 	Provider *p = 0;
@@ -1508,6 +1521,28 @@ InitializationVector::InitializationVector(const QByteArray &a)
 	set(SecureArray(a));
 }
 
+//----------------------------------------------------------------------------
+// AuthTag
+//----------------------------------------------------------------------------
+AuthTag::AuthTag()
+{
+}
+
+AuthTag::AuthTag(int size)
+{
+	resize(size);
+}
+
+AuthTag::AuthTag(const SecureArray &a)
+{
+	set(a);
+}
+
+AuthTag::AuthTag(const QByteArray &a)
+{
+	set(SecureArray(a));
+}
+
 //----------------------------------------------------------------------------
 // Event
 //----------------------------------------------------------------------------
